@@ -81,8 +81,7 @@ private:
     // Only apply font_style to the font
     // Not the padding. So calling apply_element_style with font_style = {}
     reset_element_style(stream);
-    apply_element_style(stream, *format.font_color_, *format.font_background_color_,
-                        {});
+    apply_element_style(stream, *format.font_color_, *format.font_background_color_, {});
 
     if (text_with_padding_size < column_width) {
       for (size_t j = 0; j < (column_width - text_with_padding_size); ++j) {
@@ -107,8 +106,7 @@ private:
       // Only apply font_style to the font
       // Not the padding. So calling apply_element_style with font_style = {}
       reset_element_style(stream);
-      apply_element_style(stream, *format.font_color_, *format.font_background_color_,
-                          {});
+      apply_element_style(stream, *format.font_color_, *format.font_background_color_, {});
 
       for (size_t j = 0; j < num_spaces / 2; ++j)
         stream << " ";
@@ -124,8 +122,7 @@ private:
       // Only apply font_style to the font
       // Not the padding. So calling apply_element_style with font_style = {}
       reset_element_style(stream);
-      apply_element_style(stream, *format.font_color_, *format.font_background_color_,
-                          {});
+      apply_element_style(stream, *format.font_color_, *format.font_background_color_, {});
 
       for (size_t j = 0; j < num_spaces - num_spaces_before; ++j)
         stream << " ";
@@ -148,8 +145,7 @@ private:
     // Only apply font_style to the font
     // Not the padding. So calling apply_element_style with font_style = {}
     reset_element_style(stream);
-    apply_element_style(stream, *format.font_color_, *format.font_background_color_,
-                        {});
+    apply_element_style(stream, *format.font_color_, *format.font_background_color_, {});
   }
 
   static void apply_font_style(std::ostream &stream, FontStyle style) {
